from templates import command_template_pb2 as _command_template_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StepTemplate(_message.Message):
    __slots__ = ("unique_id", "name", "is_parallel", "command_templates", "index")
    UNIQUE_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    IS_PARALLEL_FIELD_NUMBER: _ClassVar[int]
    COMMAND_TEMPLATES_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    unique_id: str
    name: str
    is_parallel: bool
    command_templates: _containers.RepeatedCompositeFieldContainer[_command_template_pb2.CommandTemplate]
    index: int
    def __init__(self, unique_id: _Optional[str] = ..., name: _Optional[str] = ..., is_parallel: bool = ..., command_templates: _Optional[_Iterable[_Union[_command_template_pb2.CommandTemplate, _Mapping]]] = ..., index: _Optional[int] = ...) -> None: ...



import ares_data_schema_pb2 as _ares_data_schema_pb2
import ares_struct_pb2 as _ares_struct_pb2
from scripting import symbol_kind_pb2 as _symbol_kind_pb2
from scripting import symbol_tag_pb2 as _symbol_tag_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ScriptSymbolMetadata(_message.Message):
    __slots__ = ("identifier", "parent_identifier", "kind", "tags", "detail", "documentation", "value_shape", "function_shape")
    class ValueShape(_message.Message):
        __slots__ = ("schema", "value")
        SCHEMA_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        schema: _ares_data_schema_pb2.AresValueSchema
        value: _ares_struct_pb2.AresValue
        def __init__(self, schema: _Optional[_Union[_ares_data_schema_pb2.AresValueSchema, _Mapping]] = ..., value: _Optional[_Union[_ares_struct_pb2.AresValue, _Mapping]] = ...) -> None: ...
    class FunctionShape(_message.Message):
        __slots__ = ("input_schema", "output_schema")
        INPUT_SCHEMA_FIELD_NUMBER: _ClassVar[int]
        OUTPUT_SCHEMA_FIELD_NUMBER: _ClassVar[int]
        input_schema: _ares_data_schema_pb2.AresStructSchema
        output_schema: _ares_data_schema_pb2.AresValueSchema
        def __init__(self, input_schema: _Optional[_Union[_ares_data_schema_pb2.AresStructSchema, _Mapping]] = ..., output_schema: _Optional[_Union[_ares_data_schema_pb2.AresValueSchema, _Mapping]] = ...) -> None: ...
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    PARENT_IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    KIND_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    DETAIL_FIELD_NUMBER: _ClassVar[int]
    DOCUMENTATION_FIELD_NUMBER: _ClassVar[int]
    VALUE_SHAPE_FIELD_NUMBER: _ClassVar[int]
    FUNCTION_SHAPE_FIELD_NUMBER: _ClassVar[int]
    identifier: str
    parent_identifier: str
    kind: _symbol_kind_pb2.SymbolKind
    tags: _containers.RepeatedScalarFieldContainer[_symbol_tag_pb2.SymbolTag]
    detail: str
    documentation: str
    value_shape: ScriptSymbolMetadata.ValueShape
    function_shape: ScriptSymbolMetadata.FunctionShape
    def __init__(self, identifier: _Optional[str] = ..., parent_identifier: _Optional[str] = ..., kind: _Optional[_Union[_symbol_kind_pb2.SymbolKind, str]] = ..., tags: _Optional[_Iterable[_Union[_symbol_tag_pb2.SymbolTag, str]]] = ..., detail: _Optional[str] = ..., documentation: _Optional[str] = ..., value_shape: _Optional[_Union[ScriptSymbolMetadata.ValueShape, _Mapping]] = ..., function_shape: _Optional[_Union[ScriptSymbolMetadata.FunctionShape, _Mapping]] = ...) -> None: ...



from analyzing import analyzer_info_pb2 as _analyzer_info_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AnalysisOverview(_message.Message):
    __slots__ = ("unique_id", "experiment_overview_id", "result", "analyzer_info")
    UNIQUE_ID_FIELD_NUMBER: _ClassVar[int]
    EXPERIMENT_OVERVIEW_ID_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    ANALYZER_INFO_FIELD_NUMBER: _ClassVar[int]
    unique_id: str
    experiment_overview_id: str
    result: float
    analyzer_info: _analyzer_info_pb2.AnalyzerInfo
    def __init__(self, unique_id: _Optional[str] = ..., experiment_overview_id: _Optional[str] = ..., result: _Optional[float] = ..., analyzer_info: _Optional[_Union[_analyzer_info_pb2.AnalyzerInfo, _Mapping]] = ...) -> None: ...



import ares_data_schema_pb2 as _ares_data_schema_pb2
from device import device_command_descriptor_pb2 as _device_command_descriptor_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DeviceInfo(_message.Message):
    __slots__ = ("unique_id", "name", "type", "description", "version", "url", "settings_schema", "commands")
    UNIQUE_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    SETTINGS_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    COMMANDS_FIELD_NUMBER: _ClassVar[int]
    unique_id: str
    name: str
    type: str
    description: str
    version: str
    url: str
    settings_schema: _ares_data_schema_pb2.AresStructSchema
    commands: _containers.RepeatedCompositeFieldContainer[_device_command_descriptor_pb2.DeviceCommandDescriptor]
    def __init__(self, unique_id: _Optional[str] = ..., name: _Optional[str] = ..., type: _Optional[str] = ..., description: _Optional[str] = ..., version: _Optional[str] = ..., url: _Optional[str] = ..., settings_schema: _Optional[_Union[_ares_data_schema_pb2.AresStructSchema, _Mapping]] = ..., commands: _Optional[_Iterable[_Union[_device_command_descriptor_pb2.DeviceCommandDescriptor, _Mapping]]] = ...) -> None: ...



import sys
from os import path

# needed for the "renaming" package
sys.path.append(path.dirname(__file__))
from pathlib import Path
import tempfile
from typing import Iterator
import grpc_tools.protoc
from renaming.fdsetgen import CustomProtoc

from hatchling.builders.hooks.plugin.interface import BuildHookInterface

_SCRIPT_PATH = Path(__file__).absolute()
PROJECT_PATH = path.join(_SCRIPT_PATH.parent, "src", "ares_datamodel")
PROTO_DIR = path.join(_SCRIPT_PATH.parent.parent, "protos")
DATAMODEL_PATH = path.join(PROTO_DIR, "datamodel")
SERVICES_PATH = path.join(PROTO_DIR, "services")

class CustomBuildHook(BuildHookInterface):
    PLUGIN_NAME = "protogen"

    def initialize(self, version: str, build_data: dict[str, any]) -> None:
        grpc_tools_dir = path.dirname(grpc_tools.__file__)
        # The well-known types are in the included directory of the protobuf library
        # which is bundled with grpcio-tools
        proto_include_dir = path.join(grpc_tools_dir, "_proto")

        protoc_args = [
            "grpc_tools.protoc",
            f"--proto_path={DATAMODEL_PATH}",
            f"--proto_path={SERVICES_PATH}",
            f"--proto_path={proto_include_dir}",
            f"--python_out={PROJECT_PATH}",
            f"--pyi_out={PROJECT_PATH}",
            f"--grpc_python_out={PROJECT_PATH}",
        ]

        for proto_file in grab_protos(PROTO_DIR):
            proto_path_str = str(proto_file.absolute())

            with tempfile.NamedTemporaryFile(delete=False) as f:
              descriptor_path = Path(f.name)
              test = f"--descriptor_set_out={descriptor_path}"
              args_with_file = protoc_args + [test, proto_path_str]
              result = grpc_tools.protoc.main(args_with_file)

              # We need to fix the imports as the standard protoc compiler
              # does not do well with relative paths
              generator = CustomProtoc(descriptor_path)
              generator.fix_imports(python_out=Path(PROJECT_PATH), create_package=False, overwrite_callback=overwrite_callback, module_suffixes=["_pb2.py", "_pb2_grpc.py"], exclude_imports_glob=["google/protobuf/*"])

              if result == 0:
                  print(f"Generated proto from: {proto_path_str}")
              if result != 0:
                  raise RuntimeError(f"Failed to compile proto file {proto_path_str}")


def grab_protos(dir: str) -> Iterator[Path]:
    search_path = Path(dir)

    for file_path in search_path.rglob("*.proto"):
        yield file_path


def overwrite_callback(python_file: Path, new_code: str):
    try:
        with open(python_file, 'w') as file:
            file.write(new_code)

        print(f"File {python_file} updated")
    except FileNotFoundError:
        print(f"Error: The file '{python_file}' was not found.")

    except IOError as e:
        print(f"An I/O error occurred: {e}")


import ares_struct_pb2 as _ares_struct_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CommandResult(_message.Message):
    __slots__ = ("unique_id", "result", "success", "error", "await_user_input")
    UNIQUE_ID_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    AWAIT_USER_INPUT_FIELD_NUMBER: _ClassVar[int]
    unique_id: str
    result: _ares_struct_pb2.AresValue
    success: bool
    error: str
    await_user_input: bool
    def __init__(self, unique_id: _Optional[str] = ..., result: _Optional[_Union[_ares_struct_pb2.AresValue, _Mapping]] = ..., success: bool = ..., error: _Optional[str] = ..., await_user_input: bool = ...) -> None: ...



"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings
from . import ares_automation_pb2 as ares__automation__pb2
from . import execution_status_messages_pb2 as execution__status__messages__pb2
from . import execution_summary_messages_pb2 as execution__summary__messages__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import project_pb2 as project__pb2
from .templates import campaign_template_pb2 as templates_dot_campaign__template__pb2
GRPC_GENERATED_VERSION = '1.78.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(f'The grpc package installed is at version {GRPC_VERSION},' + ' but the generated code in ares_automation_pb2_grpc.py depends on' + f' grpcio>={GRPC_GENERATED_VERSION}.' + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}' + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.')

class AresAutomationStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAllCampaigns = channel.unary_unary('/ares.services.AresAutomation/GetAllCampaigns', request_serializer=ares__automation__pb2.GetAllCampaignsRequest.SerializeToString, response_deserializer=ares__automation__pb2.GetAllCampaignsResponse.FromString, _registered_method=True)
        self.GetSingleCampaign = channel.unary_unary('/ares.services.AresAutomation/GetSingleCampaign', request_serializer=ares__automation__pb2.CampaignRequest.SerializeToString, response_deserializer=templates_dot_campaign__template__pb2.CampaignTemplate.FromString, _registered_method=True)
        self.RemoveCampaign = channel.unary_unary('/ares.services.AresAutomation/RemoveCampaign', request_serializer=ares__automation__pb2.CampaignRequest.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.GetCopyOfCampaign = channel.unary_unary('/ares.services.AresAutomation/GetCopyOfCampaign', request_serializer=ares__automation__pb2.CampaignRequest.SerializeToString, response_deserializer=ares__automation__pb2.GetCopyOfCampaignResponse.FromString, _registered_method=True)
        self.CampaignExists = channel.unary_unary('/ares.services.AresAutomation/CampaignExists', request_serializer=ares__automation__pb2.CampaignRequest.SerializeToString, response_deserializer=google_dot_protobuf_dot_wrappers__pb2.BoolValue.FromString, _registered_method=True)
        self.AddCampaign = channel.unary_unary('/ares.services.AresAutomation/AddCampaign', request_serializer=ares__automation__pb2.AddOrUpdateCampaignRequest.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.UpdateCampaign = channel.unary_unary('/ares.services.AresAutomation/UpdateCampaign', request_serializer=ares__automation__pb2.AddOrUpdateCampaignRequest.SerializeToString, response_deserializer=templates_dot_campaign__template__pb2.CampaignTemplate.FromString, _registered_method=True)
        self.CheckExecutionEligibility = channel.unary_unary('/ares.services.AresAutomation/CheckExecutionEligibility', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=ares__automation__pb2.CheckExecutionEligibilityResponse.FromString, _registered_method=True)
        self.GetAllProjects = channel.unary_unary('/ares.services.AresAutomation/GetAllProjects', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=ares__automation__pb2.ProjectsResponse.FromString, _registered_method=True)
        self.GetProject = channel.unary_unary('/ares.services.AresAutomation/GetProject', request_serializer=ares__automation__pb2.ProjectRequest.SerializeToString, response_deserializer=project__pb2.Project.FromString, _registered_method=True)
        self.RemoveProject = channel.unary_unary('/ares.services.AresAutomation/RemoveProject', request_serializer=ares__automation__pb2.ProjectRequest.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.AddProject = channel.unary_unary('/ares.services.AresAutomation/AddProject', request_serializer=project__pb2.Project.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.GetAllTags = channel.unary_unary('/ares.services.AresAutomation/GetAllTags', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=ares__automation__pb2.TagsResponse.FromString, _registered_method=True)
        self.AddTag = channel.unary_unary('/ares.services.AresAutomation/AddTag', request_serializer=ares__automation__pb2.TagRequest.SerializeToString, response_deserializer=ares__automation__pb2.TagsResponse.FromString, _registered_method=True)
        self.RemoveTag = channel.unary_unary('/ares.services.AresAutomation/RemoveTag', request_serializer=ares__automation__pb2.TagRequest.SerializeToString, response_deserializer=ares__automation__pb2.TagsResponse.FromString, _registered_method=True)
        self.SetCampaignForExecution = channel.unary_unary('/ares.services.AresAutomation/SetCampaignForExecution', request_serializer=ares__automation__pb2.CampaignRequest.SerializeToString, response_deserializer=templates_dot_campaign__template__pb2.CampaignTemplate.FromString, _registered_method=True)
        self.GetCurrentlySelectedCampaign = channel.unary_unary('/ares.services.AresAutomation/GetCurrentlySelectedCampaign', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=ares__automation__pb2.CampaignResponse.FromString, _registered_method=True)
        self.StartExecution = channel.unary_unary('/ares.services.AresAutomation/StartExecution', request_serializer=ares__automation__pb2.StartCampaignRequest.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.StopExecution = channel.unary_unary('/ares.services.AresAutomation/StopExecution', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.PauseExecution = channel.unary_unary('/ares.services.AresAutomation/PauseExecution', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.ResumeExecution = channel.unary_unary('/ares.services.AresAutomation/ResumeExecution', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.GetAssignedStopConditions = channel.unary_unary('/ares.services.AresAutomation/GetAssignedStopConditions', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=ares__automation__pb2.StartStopConditionsResponse.FromString, _registered_method=True)
        self.GetReplanRate = channel.unary_unary('/ares.services.AresAutomation/GetReplanRate', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=ares__automation__pb2.GetReplanRateResponse.FromString, _registered_method=True)
        self.GetFailedStartConditions = channel.unary_unary('/ares.services.AresAutomation/GetFailedStartConditions', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=ares__automation__pb2.StartStopConditionsResponse.FromString, _registered_method=True)
        self.GetPreliminaryFailedStartConditions = channel.unary_unary('/ares.services.AresAutomation/GetPreliminaryFailedStartConditions', request_serializer=templates_dot_campaign__template__pb2.CampaignTemplate.SerializeToString, response_deserializer=ares__automation__pb2.StartStopConditionsResponse.FromString, _registered_method=True)
        self.SetNumExperimentsStopCondition = channel.unary_unary('/ares.services.AresAutomation/SetNumExperimentsStopCondition', request_serializer=ares__automation__pb2.NumExperimentsCondition.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.SetReplanRate = channel.unary_unary('/ares.services.AresAutomation/SetReplanRate', request_serializer=ares__automation__pb2.ReplanRate.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.SetAnalysisResultStopCondition = channel.unary_unary('/ares.services.AresAutomation/SetAnalysisResultStopCondition', request_serializer=ares__automation__pb2.AnalysisResultCondition.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.GetActiveStopCondition = channel.unary_unary('/ares.services.AresAutomation/GetActiveStopCondition', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=ares__automation__pb2.ExperimentStopConditionResponse.FromString, _registered_method=True)
        self.RemoveStopCondition = channel.unary_unary('/ares.services.AresAutomation/RemoveStopCondition', request_serializer=ares__automation__pb2.StartStopCondition.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.GetExecutionStatusStream = channel.unary_stream('/ares.services.AresAutomation/GetExecutionStatusStream', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=execution__status__messages__pb2.ExperimentExecutionStatus.FromString, _registered_method=True)
        self.GetStartupExecutionStatusStream = channel.unary_stream('/ares.services.AresAutomation/GetStartupExecutionStatusStream', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=execution__status__messages__pb2.CampaignStartupStatus.FromString, _registered_method=True)
        self.GetCloseoutExecutionStatusStream = channel.unary_stream('/ares.services.AresAutomation/GetCloseoutExecutionStatusStream', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=execution__status__messages__pb2.CampaignCloseoutStatus.FromString, _registered_method=True)
        self.GetCampaignExecutionStatus = channel.unary_unary('/ares.services.AresAutomation/GetCampaignExecutionStatus', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=ares__automation__pb2.CampaignExecutionStatusResponse.FromString, _registered_method=True)
        self.GetCampaignExecutionStateStream = channel.unary_stream('/ares.services.AresAutomation/GetCampaignExecutionStateStream', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=execution__status__messages__pb2.CampaignExecutionState.FromString, _registered_method=True)
        self.GetAvailableCampaignExecutionSummaries = channel.unary_unary('/ares.services.AresAutomation/GetAvailableCampaignExecutionSummaries', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=ares__automation__pb2.AvailableCampaignExecutionSummariesResponse.FromString, _registered_method=True)
        self.GetCampaignSummary = channel.unary_unary('/ares.services.AresAutomation/GetCampaignSummary', request_serializer=ares__automation__pb2.CampaignExecutionSummaryRequest.SerializeToString, response_deserializer=execution__summary__messages__pb2.CampaignExecutionSummary.FromString, _registered_method=True)

class AresAutomationServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetAllCampaigns(self, request, context):
        """Campaigns
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSingleCampaign(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveCampaign(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCopyOfCampaign(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CampaignExists(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddCampaign(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateCampaign(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckExecutionEligibility(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllProjects(self, request, context):
        """Projects
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllTags(self, request, context):
        """Tags
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddTag(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveTag(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetCampaignForExecution(self, request, context):
        """Execution
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCurrentlySelectedCampaign(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartExecution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopExecution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseExecution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResumeExecution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAssignedStopConditions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetReplanRate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFailedStartConditions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPreliminaryFailedStartConditions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetNumExperimentsStopCondition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetReplanRate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAnalysisResultStopCondition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetActiveStopCondition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveStopCondition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExecutionStatusStream(self, request, context):
        """Gets a stream of experiment execution statuses that can be observed in real time as experiment is running
        Works best after grabbing all the execution statuses which then lets you know how many experiments have been run
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStartupExecutionStatusStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCloseoutExecutionStatusStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCampaignExecutionStatus(self, request, context):
        """Gets the current status of a campaign execution assuming one is running
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCampaignExecutionStateStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAvailableCampaignExecutionSummaries(self, request, context):
        """Summaries
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCampaignSummary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_AresAutomationServicer_to_server(servicer, server):
    rpc_method_handlers = {'GetAllCampaigns': grpc.unary_unary_rpc_method_handler(servicer.GetAllCampaigns, request_deserializer=ares__automation__pb2.GetAllCampaignsRequest.FromString, response_serializer=ares__automation__pb2.GetAllCampaignsResponse.SerializeToString), 'GetSingleCampaign': grpc.unary_unary_rpc_method_handler(servicer.GetSingleCampaign, request_deserializer=ares__automation__pb2.CampaignRequest.FromString, response_serializer=templates_dot_campaign__template__pb2.CampaignTemplate.SerializeToString), 'RemoveCampaign': grpc.unary_unary_rpc_method_handler(servicer.RemoveCampaign, request_deserializer=ares__automation__pb2.CampaignRequest.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'GetCopyOfCampaign': grpc.unary_unary_rpc_method_handler(servicer.GetCopyOfCampaign, request_deserializer=ares__automation__pb2.CampaignRequest.FromString, response_serializer=ares__automation__pb2.GetCopyOfCampaignResponse.SerializeToString), 'CampaignExists': grpc.unary_unary_rpc_method_handler(servicer.CampaignExists, request_deserializer=ares__automation__pb2.CampaignRequest.FromString, response_serializer=google_dot_protobuf_dot_wrappers__pb2.BoolValue.SerializeToString), 'AddCampaign': grpc.unary_unary_rpc_method_handler(servicer.AddCampaign, request_deserializer=ares__automation__pb2.AddOrUpdateCampaignRequest.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'UpdateCampaign': grpc.unary_unary_rpc_method_handler(servicer.UpdateCampaign, request_deserializer=ares__automation__pb2.AddOrUpdateCampaignRequest.FromString, response_serializer=templates_dot_campaign__template__pb2.CampaignTemplate.SerializeToString), 'CheckExecutionEligibility': grpc.unary_unary_rpc_method_handler(servicer.CheckExecutionEligibility, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=ares__automation__pb2.CheckExecutionEligibilityResponse.SerializeToString), 'GetAllProjects': grpc.unary_unary_rpc_method_handler(servicer.GetAllProjects, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=ares__automation__pb2.ProjectsResponse.SerializeToString), 'GetProject': grpc.unary_unary_rpc_method_handler(servicer.GetProject, request_deserializer=ares__automation__pb2.ProjectRequest.FromString, response_serializer=project__pb2.Project.SerializeToString), 'RemoveProject': grpc.unary_unary_rpc_method_handler(servicer.RemoveProject, request_deserializer=ares__automation__pb2.ProjectRequest.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'AddProject': grpc.unary_unary_rpc_method_handler(servicer.AddProject, request_deserializer=project__pb2.Project.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'GetAllTags': grpc.unary_unary_rpc_method_handler(servicer.GetAllTags, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=ares__automation__pb2.TagsResponse.SerializeToString), 'AddTag': grpc.unary_unary_rpc_method_handler(servicer.AddTag, request_deserializer=ares__automation__pb2.TagRequest.FromString, response_serializer=ares__automation__pb2.TagsResponse.SerializeToString), 'RemoveTag': grpc.unary_unary_rpc_method_handler(servicer.RemoveTag, request_deserializer=ares__automation__pb2.TagRequest.FromString, response_serializer=ares__automation__pb2.TagsResponse.SerializeToString), 'SetCampaignForExecution': grpc.unary_unary_rpc_method_handler(servicer.SetCampaignForExecution, request_deserializer=ares__automation__pb2.CampaignRequest.FromString, response_serializer=templates_dot_campaign__template__pb2.CampaignTemplate.SerializeToString), 'GetCurrentlySelectedCampaign': grpc.unary_unary_rpc_method_handler(servicer.GetCurrentlySelectedCampaign, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=ares__automation__pb2.CampaignResponse.SerializeToString), 'StartExecution': grpc.unary_unary_rpc_method_handler(servicer.StartExecution, request_deserializer=ares__automation__pb2.StartCampaignRequest.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'StopExecution': grpc.unary_unary_rpc_method_handler(servicer.StopExecution, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'PauseExecution': grpc.unary_unary_rpc_method_handler(servicer.PauseExecution, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'ResumeExecution': grpc.unary_unary_rpc_method_handler(servicer.ResumeExecution, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'GetAssignedStopConditions': grpc.unary_unary_rpc_method_handler(servicer.GetAssignedStopConditions, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=ares__automation__pb2.StartStopConditionsResponse.SerializeToString), 'GetReplanRate': grpc.unary_unary_rpc_method_handler(servicer.GetReplanRate, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=ares__automation__pb2.GetReplanRateResponse.SerializeToString), 'GetFailedStartConditions': grpc.unary_unary_rpc_method_handler(servicer.GetFailedStartConditions, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=ares__automation__pb2.StartStopConditionsResponse.SerializeToString), 'GetPreliminaryFailedStartConditions': grpc.unary_unary_rpc_method_handler(servicer.GetPreliminaryFailedStartConditions, request_deserializer=templates_dot_campaign__template__pb2.CampaignTemplate.FromString, response_serializer=ares__automation__pb2.StartStopConditionsResponse.SerializeToString), 'SetNumExperimentsStopCondition': grpc.unary_unary_rpc_method_handler(servicer.SetNumExperimentsStopCondition, request_deserializer=ares__automation__pb2.NumExperimentsCondition.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'SetReplanRate': grpc.unary_unary_rpc_method_handler(servicer.SetReplanRate, request_deserializer=ares__automation__pb2.ReplanRate.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'SetAnalysisResultStopCondition': grpc.unary_unary_rpc_method_handler(servicer.SetAnalysisResultStopCondition, request_deserializer=ares__automation__pb2.AnalysisResultCondition.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'GetActiveStopCondition': grpc.unary_unary_rpc_method_handler(servicer.GetActiveStopCondition, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=ares__automation__pb2.ExperimentStopConditionResponse.SerializeToString), 'RemoveStopCondition': grpc.unary_unary_rpc_method_handler(servicer.RemoveStopCondition, request_deserializer=ares__automation__pb2.StartStopCondition.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'GetExecutionStatusStream': grpc.unary_stream_rpc_method_handler(servicer.GetExecutionStatusStream, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=execution__status__messages__pb2.ExperimentExecutionStatus.SerializeToString), 'GetStartupExecutionStatusStream': grpc.unary_stream_rpc_method_handler(servicer.GetStartupExecutionStatusStream, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=execution__status__messages__pb2.CampaignStartupStatus.SerializeToString), 'GetCloseoutExecutionStatusStream': grpc.unary_stream_rpc_method_handler(servicer.GetCloseoutExecutionStatusStream, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=execution__status__messages__pb2.CampaignCloseoutStatus.SerializeToString), 'GetCampaignExecutionStatus': grpc.unary_unary_rpc_method_handler(servicer.GetCampaignExecutionStatus, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=ares__automation__pb2.CampaignExecutionStatusResponse.SerializeToString), 'GetCampaignExecutionStateStream': grpc.unary_stream_rpc_method_handler(servicer.GetCampaignExecutionStateStream, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=execution__status__messages__pb2.CampaignExecutionState.SerializeToString), 'GetAvailableCampaignExecutionSummaries': grpc.unary_unary_rpc_method_handler(servicer.GetAvailableCampaignExecutionSummaries, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=ares__automation__pb2.AvailableCampaignExecutionSummariesResponse.SerializeToString), 'GetCampaignSummary': grpc.unary_unary_rpc_method_handler(servicer.GetCampaignSummary, request_deserializer=ares__automation__pb2.CampaignExecutionSummaryRequest.FromString, response_serializer=execution__summary__messages__pb2.CampaignExecutionSummary.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('ares.services.AresAutomation', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ares.services.AresAutomation', rpc_method_handlers)

class AresAutomation(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetAllCampaigns(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/GetAllCampaigns', ares__automation__pb2.GetAllCampaignsRequest.SerializeToString, ares__automation__pb2.GetAllCampaignsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetSingleCampaign(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/GetSingleCampaign', ares__automation__pb2.CampaignRequest.SerializeToString, templates_dot_campaign__template__pb2.CampaignTemplate.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def RemoveCampaign(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/RemoveCampaign', ares__automation__pb2.CampaignRequest.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetCopyOfCampaign(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/GetCopyOfCampaign', ares__automation__pb2.CampaignRequest.SerializeToString, ares__automation__pb2.GetCopyOfCampaignResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def CampaignExists(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/CampaignExists', ares__automation__pb2.CampaignRequest.SerializeToString, google_dot_protobuf_dot_wrappers__pb2.BoolValue.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def AddCampaign(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/AddCampaign', ares__automation__pb2.AddOrUpdateCampaignRequest.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def UpdateCampaign(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/UpdateCampaign', ares__automation__pb2.AddOrUpdateCampaignRequest.SerializeToString, templates_dot_campaign__template__pb2.CampaignTemplate.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def CheckExecutionEligibility(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/CheckExecutionEligibility', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, ares__automation__pb2.CheckExecutionEligibilityResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetAllProjects(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/GetAllProjects', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, ares__automation__pb2.ProjectsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetProject(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/GetProject', ares__automation__pb2.ProjectRequest.SerializeToString, project__pb2.Project.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def RemoveProject(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/RemoveProject', ares__automation__pb2.ProjectRequest.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def AddProject(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/AddProject', project__pb2.Project.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetAllTags(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/GetAllTags', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, ares__automation__pb2.TagsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def AddTag(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/AddTag', ares__automation__pb2.TagRequest.SerializeToString, ares__automation__pb2.TagsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def RemoveTag(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/RemoveTag', ares__automation__pb2.TagRequest.SerializeToString, ares__automation__pb2.TagsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def SetCampaignForExecution(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/SetCampaignForExecution', ares__automation__pb2.CampaignRequest.SerializeToString, templates_dot_campaign__template__pb2.CampaignTemplate.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetCurrentlySelectedCampaign(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/GetCurrentlySelectedCampaign', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, ares__automation__pb2.CampaignResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def StartExecution(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/StartExecution', ares__automation__pb2.StartCampaignRequest.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def StopExecution(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/StopExecution', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def PauseExecution(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/PauseExecution', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def ResumeExecution(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/ResumeExecution', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetAssignedStopConditions(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/GetAssignedStopConditions', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, ares__automation__pb2.StartStopConditionsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetReplanRate(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/GetReplanRate', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, ares__automation__pb2.GetReplanRateResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetFailedStartConditions(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/GetFailedStartConditions', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, ares__automation__pb2.StartStopConditionsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetPreliminaryFailedStartConditions(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/GetPreliminaryFailedStartConditions', templates_dot_campaign__template__pb2.CampaignTemplate.SerializeToString, ares__automation__pb2.StartStopConditionsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def SetNumExperimentsStopCondition(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/SetNumExperimentsStopCondition', ares__automation__pb2.NumExperimentsCondition.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def SetReplanRate(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/SetReplanRate', ares__automation__pb2.ReplanRate.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def SetAnalysisResultStopCondition(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/SetAnalysisResultStopCondition', ares__automation__pb2.AnalysisResultCondition.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetActiveStopCondition(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/GetActiveStopCondition', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, ares__automation__pb2.ExperimentStopConditionResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def RemoveStopCondition(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/RemoveStopCondition', ares__automation__pb2.StartStopCondition.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetExecutionStatusStream(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_stream(request, target, '/ares.services.AresAutomation/GetExecutionStatusStream', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, execution__status__messages__pb2.ExperimentExecutionStatus.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetStartupExecutionStatusStream(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_stream(request, target, '/ares.services.AresAutomation/GetStartupExecutionStatusStream', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, execution__status__messages__pb2.CampaignStartupStatus.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetCloseoutExecutionStatusStream(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_stream(request, target, '/ares.services.AresAutomation/GetCloseoutExecutionStatusStream', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, execution__status__messages__pb2.CampaignCloseoutStatus.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetCampaignExecutionStatus(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/GetCampaignExecutionStatus', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, ares__automation__pb2.CampaignExecutionStatusResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetCampaignExecutionStateStream(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_stream(request, target, '/ares.services.AresAutomation/GetCampaignExecutionStateStream', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, execution__status__messages__pb2.CampaignExecutionState.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetAvailableCampaignExecutionSummaries(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/GetAvailableCampaignExecutionSummaries', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, ares__automation__pb2.AvailableCampaignExecutionSummariesResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetCampaignSummary(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresAutomation/GetCampaignSummary', ares__automation__pb2.CampaignExecutionSummaryRequest.SerializeToString, execution__summary__messages__pb2.CampaignExecutionSummary.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)


import ares_data_schema_pb2 as _ares_data_schema_pb2
import ares_struct_pb2 as _ares_struct_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GlobalVariableSymbol(_message.Message):
    __slots__ = ("name", "description", "schema", "value")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    schema: _ares_data_schema_pb2.AresValueSchema
    value: _ares_struct_pb2.AresValue
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., schema: _Optional[_Union[_ares_data_schema_pb2.AresValueSchema, _Mapping]] = ..., value: _Optional[_Union[_ares_struct_pb2.AresValue, _Mapping]] = ...) -> None: ...



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_scripting_service.proto')
_sym_db = _symbol_database.Default()
from . import ares_struct_pb2 as ares__struct__pb2
from .scripting import completion_pb2 as scripting_dot_completion__pb2
from .scripting import diagnostic_pb2 as scripting_dot_diagnostic__pb2
from .scripting import navigation_pb2 as scripting_dot_navigation__pb2
from .scripting import script_summary_step_pb2 as scripting_dot_script__summary__step__pb2
from .scripting import script_symbol_metadata_pb2 as scripting_dot_script__symbol__metadata__pb2
from .scripting import signature_help_pb2 as scripting_dot_signature__help__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cares_scripting_service.proto\x12\rares.services\x1a\x11ares_struct.proto\x1a\x1ascripting/completion.proto\x1a\x1ascripting/diagnostic.proto\x1a\x1ascripting/navigation.proto\x1a#scripting/script_summary_step.proto\x1a&scripting/script_symbol_metadata.proto\x1a\x1escripting/signature_help.proto"(\n\x16ScriptExecutionRequest\x12\x0e\n\x06script\x18\x01 \x01(\t"\xdb\x03\n\x14ScriptExecutionEvent\x12\x10\n\x08sequence\x18\x01 \x01(\x03\x12<\n\x11execution_started\x18\x02 \x01(\x0b2\x1f.ares.services.ExecutionStartedH\x00\x12@\n\x13execution_completed\x18\x03 \x01(\x0b2!.ares.services.ExecutionCompletedH\x00\x12:\n\x10execution_failed\x18\x04 \x01(\x0b2\x1e.ares.services.ExecutionFailedH\x00\x126\n\x0econsole_output\x18\x05 \x01(\x0b2\x1c.ares.services.ConsoleOutputH\x00\x12:\n\x10function_started\x18\x06 \x01(\x0b2\x1e.ares.services.FunctionStartedH\x00\x12>\n\x12function_completed\x18\x07 \x01(\x0b2 .ares.services.FunctionCompletedH\x00\x128\n\x0ffunction_failed\x18\x08 \x01(\x0b2\x1d.ares.services.FunctionFailedH\x00B\x07\n\x05event"\x12\n\x10ExecutionStarted"\x14\n\x12ExecutionCompleted" \n\x0fExecutionFailed\x12\r\n\x05error\x18\x01 \x01(\t"\x1f\n\rConsoleOutput\x12\x0e\n\x06output\x18\x01 \x01(\t"\x82\x01\n\x0fFunctionStarted\x12\x0f\n\x07call_id\x18\x01 \x01(\t\x12\x16\n\x0eparent_call_id\x18\x02 \x01(\t\x12F\n\ninvocation\x18\x03 \x01(\x0b22.ares.datamodel.scripting.ScriptFunctionInvocation"O\n\x11FunctionCompleted\x12\x0f\n\x07call_id\x18\x01 \x01(\t\x12)\n\x06result\x18\x02 \x01(\x0b2\x19.ares.datamodel.AresValue"0\n\x0eFunctionFailed\x12\x0f\n\x07call_id\x18\x01 \x01(\t\x12\r\n\x05error\x18\x02 \x01(\t"\'\n\x15ValidateScriptRequest\x12\x0e\n\x06script\x18\x01 \x01(\t"S\n\x16ValidateScriptResponse\x129\n\x0bdiagnostics\x18\x01 \x03(\x0b2$.ares.datamodel.scripting.Diagnostic"_\n\x14ScriptSummaryRequest\x12\x0e\n\x06script\x18\x01 \x01(\t\x12\x1e\n\x16include_user_functions\x18\x02 \x01(\x08\x12\x17\n\x0finclude_lambdas\x18\x03 \x01(\x08"\x95\x01\n\x15ScriptSummaryResponse\x12A\n\x05steps\x18\x01 \x03(\x0b22.ares.datamodel.scripting.ScriptFunctionInvocation\x129\n\x0bdiagnostics\x18\x02 \x03(\x0b2$.ares.datamodel.scripting.Diagnostic"{\n\x15SymbolMetadataRequest\x12\x0e\n\x06script\x18\x01 \x01(\t\x12\x13\n\x0bcursor_line\x18\x02 \x01(\x05\x12\x15\n\rcursor_column\x18\x03 \x01(\x05\x12\x17\n\nidentifier\x18\x04 \x01(\tH\x00\x88\x01\x01B\r\n\x0b_identifier"\xa4\x01\n\x16SymbolMetadataResponse\x12\r\n\x05found\x18\x01 \x01(\x08\x12@\n\x08metadata\x18\x02 \x01(\x0b2..ares.datamodel.scripting.ScriptSymbolMetadata\x129\n\x0bdiagnostics\x18\x03 \x03(\x0b2$.ares.datamodel.scripting.Diagnostic"\x93\x01\n\x11ReferencesRequest\x12\x0e\n\x06script\x18\x01 \x01(\t\x12\x13\n\x0bcursor_line\x18\x02 \x01(\x05\x12\x15\n\rcursor_column\x18\x03 \x01(\x05\x12\x17\n\nidentifier\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\x12include_definition\x18\x05 \x01(\x08B\r\n\x0b_identifier"\x8c\x01\n\x12ReferencesResponse\x12;\n\tlocations\x18\x01 \x03(\x0b2(.ares.datamodel.scripting.SymbolLocation\x129\n\x0bdiagnostics\x18\x02 \x03(\x0b2$.ares.datamodel.scripting.Diagnostic"R\n\x14SignatureHelpRequest\x12\x0e\n\x06script\x18\x01 \x01(\t\x12\x13\n\x0bcursor_line\x18\x02 \x01(\x05\x12\x15\n\rcursor_column\x18\x03 \x01(\x05"\x93\x01\n\x15SignatureHelpResponse\x12?\n\x0esignature_help\x18\x01 \x01(\x0b2\'.ares.datamodel.scripting.SignatureHelp\x129\n\x0bdiagnostics\x18\x02 \x03(\x0b2$.ares.datamodel.scripting.Diagnostic"j\n\x11CompletionRequest\x12\x0e\n\x06script\x18\x01 \x01(\t\x12\x13\n\x0bcursor_line\x18\x02 \x01(\x05\x12\x15\n\rcursor_column\x18\x03 \x01(\x05\x12\x19\n\x11trigger_character\x18\x04 \x01(\t"M\n\x12CompletionResponse\x127\n\x05items\x18\x01 \x03(\x0b2(.ares.datamodel.scripting.CompletionItem2\xa1\x05\n\x14AresScriptingService\x12]\n\rExecuteScript\x12%.ares.services.ScriptExecutionRequest\x1a#.ares.services.ScriptExecutionEvent0\x01\x12U\n\x0eGetCompletions\x12 .ares.services.CompletionRequest\x1a!.ares.services.CompletionResponse\x12]\n\x0eValidateScript\x12$.ares.services.ValidateScriptRequest\x1a%.ares.services.ValidateScriptResponse\x12]\n\x10GetScriptSummary\x12#.ares.services.ScriptSummaryRequest\x1a$.ares.services.ScriptSummaryResponse\x12`\n\x11GetSymbolMetadata\x12$.ares.services.SymbolMetadataRequest\x1a%.ares.services.SymbolMetadataResponse\x12T\n\rGetReferences\x12 .ares.services.ReferencesRequest\x1a!.ares.services.ReferencesResponse\x12]\n\x10GetSignatureHelp\x12#.ares.services.SignatureHelpRequest\x1a$.ares.services.SignatureHelpResponseb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_scripting_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_SCRIPTEXECUTIONREQUEST']._serialized_start = 259
    _globals['_SCRIPTEXECUTIONREQUEST']._serialized_end = 299
    _globals['_SCRIPTEXECUTIONEVENT']._serialized_start = 302
    _globals['_SCRIPTEXECUTIONEVENT']._serialized_end = 777
    _globals['_EXECUTIONSTARTED']._serialized_start = 779
    _globals['_EXECUTIONSTARTED']._serialized_end = 797
    _globals['_EXECUTIONCOMPLETED']._serialized_start = 799
    _globals['_EXECUTIONCOMPLETED']._serialized_end = 819
    _globals['_EXECUTIONFAILED']._serialized_start = 821
    _globals['_EXECUTIONFAILED']._serialized_end = 853
    _globals['_CONSOLEOUTPUT']._serialized_start = 855
    _globals['_CONSOLEOUTPUT']._serialized_end = 886
    _globals['_FUNCTIONSTARTED']._serialized_start = 889
    _globals['_FUNCTIONSTARTED']._serialized_end = 1019
    _globals['_FUNCTIONCOMPLETED']._serialized_start = 1021
    _globals['_FUNCTIONCOMPLETED']._serialized_end = 1100
    _globals['_FUNCTIONFAILED']._serialized_start = 1102
    _globals['_FUNCTIONFAILED']._serialized_end = 1150
    _globals['_VALIDATESCRIPTREQUEST']._serialized_start = 1152
    _globals['_VALIDATESCRIPTREQUEST']._serialized_end = 1191
    _globals['_VALIDATESCRIPTRESPONSE']._serialized_start = 1193
    _globals['_VALIDATESCRIPTRESPONSE']._serialized_end = 1276
    _globals['_SCRIPTSUMMARYREQUEST']._serialized_start = 1278
    _globals['_SCRIPTSUMMARYREQUEST']._serialized_end = 1373
    _globals['_SCRIPTSUMMARYRESPONSE']._serialized_start = 1376
    _globals['_SCRIPTSUMMARYRESPONSE']._serialized_end = 1525
    _globals['_SYMBOLMETADATAREQUEST']._serialized_start = 1527
    _globals['_SYMBOLMETADATAREQUEST']._serialized_end = 1650
    _globals['_SYMBOLMETADATARESPONSE']._serialized_start = 1653
    _globals['_SYMBOLMETADATARESPONSE']._serialized_end = 1817
    _globals['_REFERENCESREQUEST']._serialized_start = 1820
    _globals['_REFERENCESREQUEST']._serialized_end = 1967
    _globals['_REFERENCESRESPONSE']._serialized_start = 1970
    _globals['_REFERENCESRESPONSE']._serialized_end = 2110
    _globals['_SIGNATUREHELPREQUEST']._serialized_start = 2112
    _globals['_SIGNATUREHELPREQUEST']._serialized_end = 2194
    _globals['_SIGNATUREHELPRESPONSE']._serialized_start = 2197
    _globals['_SIGNATUREHELPRESPONSE']._serialized_end = 2344
    _globals['_COMPLETIONREQUEST']._serialized_start = 2346
    _globals['_COMPLETIONREQUEST']._serialized_end = 2452
    _globals['_COMPLETIONRESPONSE']._serialized_start = 2454
    _globals['_COMPLETIONRESPONSE']._serialized_end = 2531
    _globals['_ARESSCRIPTINGSERVICE']._serialized_start = 2534
    _globals['_ARESSCRIPTINGSERVICE']._serialized_end = 3207


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_data_type.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14ares_data_type.proto\x12\x0eares.datamodel*\xcc\x01\n\x0cAresDataType\x12\x14\n\x10UNSPECIFIED_TYPE\x10\x00\x12\x08\n\x04NULL\x10\x01\x12\x0b\n\x07BOOLEAN\x10\x02\x12\n\n\x06STRING\x10\x03\x12\n\n\x06NUMBER\x10\x04\x12\x10\n\x0cSTRING_ARRAY\x10\x05\x12\x10\n\x0cNUMBER_ARRAY\x10\x06\x12\x08\n\x04LIST\x10\x07\x12\n\n\x06STRUCT\x10\x08\x12\x0e\n\nBYTE_ARRAY\x10\t\x12\x07\n\x03ANY\x10\n\x12\x08\n\x04UNIT\x10\x0b\x12\x0c\n\x08FUNCTION\x10\x0c\x12\x0c\n\x08QUANTITY\x10\rb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_data_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_ARESDATATYPE']._serialized_start = 41
    _globals['_ARESDATATYPE']._serialized_end = 245


from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PollingType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    NONE: _ClassVar[PollingType]
    INTERVAL: _ClassVar[PollingType]
    ON_CHANGE: _ClassVar[PollingType]
NONE: PollingType
INTERVAL: PollingType
ON_CHANGE: PollingType

class DevicePollingSettings(_message.Message):
    __slots__ = ("device_id", "polling_type", "interval_ms")
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    POLLING_TYPE_FIELD_NUMBER: _ClassVar[int]
    INTERVAL_MS_FIELD_NUMBER: _ClassVar[int]
    device_id: str
    polling_type: PollingType
    interval_ms: int
    def __init__(self, device_id: _Optional[str] = ..., polling_type: _Optional[_Union[PollingType, str]] = ..., interval_ms: _Optional[int] = ...) -> None: ...



from device import device_connection_info_pb2 as _device_connection_info_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RemoteConnectionInfo(_message.Message):
    __slots__ = ("connection_info", "address")
    CONNECTION_INFO_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    connection_info: _device_connection_info_pb2.DeviceConnectionInfo
    address: str
    def __init__(self, connection_info: _Optional[_Union[_device_connection_info_pb2.DeviceConnectionInfo, _Mapping]] = ..., address: _Optional[str] = ...) -> None: ...



from __future__ import annotations

from typing import Any

from ares_datamodel.ares_data_schema_pb2 import QuantitySchema
from ares_datamodel.ares_quantity_type_pb2 import QuantityType
from ares_datamodel.ares_struct_pb2 import QuantityValue
from ares_datamodel.quantity_validation import (
    QUANTITY_TYPE_TO_CANONICAL_UNIT,
    validate_quantity_value,
)
from pint import Quantity, UnitRegistry
from pint.facets.plain import PlainUnit

_UNIT_REGISTRY = UnitRegistry()


def get_unit_registry() -> UnitRegistry:
    return _UNIT_REGISTRY


def to_pint_unit(unit_str: str, registry: UnitRegistry | None = None) -> PlainUnit:
    """
    Convert a unit string to a Pint unit.
    """
    ureg = registry or _UNIT_REGISTRY
    return ureg.parse_units(unit_str)


def from_pint_unit(unit: PlainUnit) -> str:
    """
    Convert a Pint unit to a formatted unit string suitable for the ARES datamodel.
    """
    return _format_units_name(unit)


def infer_quantity_type(unit: PlainUnit | str, registry: UnitRegistry | None = None) -> QuantityType:
    """
    Infer the ARES QuantityType for a given unit based on its dimensionality.
    """
    ureg = registry or _UNIT_REGISTRY
    try:
        if isinstance(unit, str):
            unit = ureg.parse_units(unit)
    except Exception:
        return QuantityType.QUANTITY_TYPE_UNSPECIFIED

    target_dim = unit.dimensionality

    # Special case for temperature differences
    if "delta_degree_Celsius" in str(unit) or "delta_kelvin" in str(unit):
        return QuantityType.TEMPERATURE_DELTA

    for qtype, canonical_unit_str in QUANTITY_TYPE_TO_CANONICAL_UNIT.items():
        if qtype == QuantityType.QUANTITY_TYPE_UNSPECIFIED:
            continue
        try:
            canonical_unit = ureg.parse_units(canonical_unit_str)
            if canonical_unit.dimensionality == target_dim:
                return qtype
        except Exception:
            continue

    return QuantityType.QUANTITY_TYPE_UNSPECIFIED


def to_pint_quantity(quantity_value: QuantityValue, registry: UnitRegistry | None = None) -> Quantity:
    """
    Convert an ARES QuantityValue to a Pint quantity.
    """
    ureg = registry or _UNIT_REGISTRY
    quantity = quantity_value.scalar * ureg.parse_units(quantity_value.unit)
    validate_quantity_value(quantity_value, registry=ureg)
    return quantity


def from_pint_quantity(
    quantity: Quantity,
    unit: str | None = None,
    registry: UnitRegistry | None = None,
) -> QuantityValue:
    """
    Convert a Pint quantity to an ARES QuantityValue.
    """
    ureg = registry or _UNIT_REGISTRY
    converted = quantity.to(ureg.parse_units(unit)) if unit else quantity
    resolved_unit = _format_units_name(converted.units)
    return QuantityValue(
        scalar=_magnitude_to_float(converted.magnitude),
        unit=resolved_unit,
        type=infer_quantity_type(converted.units, registry=ureg),
    )


def to_quantity_schema(
    unit: PlainUnit | str,
    min_scalar_value: float | None = None,
    max_scalar_value: float | None = None,
    registry: UnitRegistry | None = None,
) -> QuantitySchema:
    """
    Create a QuantitySchema from a unit and optional bounds.
    """
    ureg = registry or _UNIT_REGISTRY
    if isinstance(unit, str):
        unit = ureg.parse_units(unit)

    return QuantitySchema(
        quantity_type=infer_quantity_type(unit, registry=ureg),
        bounds_unit=from_pint_unit(unit),
        min_scalar_value=min_scalar_value,
        max_scalar_value=max_scalar_value,
    )


def convert_quantity_value_unit(
    quantity_value: QuantityValue,
    target_unit: str,
    registry: UnitRegistry | None = None,
) -> QuantityValue:
    ureg = registry or _UNIT_REGISTRY
    source = to_pint_quantity(quantity_value, registry=ureg)
    return from_pint_quantity(source, unit=target_unit, registry=ureg)


def _format_units_name(unit: PlainUnit):
    unit_str = f"{unit:~}"
    unit_str = unit_str.replace("**", "^")
    unit_str = "".join(unit_str.split())
    return unit_str


def _magnitude_to_float(magnitude: Any) -> float:
    if isinstance(magnitude, complex):
        if magnitude.imag != 0:
            raise ValueError("Complex magnitude is not supported for QuantityValue scalar conversion.")
        return float(magnitude.real)
    return float(magnitude)



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'device/device_connection_info.proto')
_sym_db = _symbol_database.Default()
from .. import ares_struct_pb2 as ares__struct__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#device/device_connection_info.proto\x12\x15ares.datamodel.device\x1a\x11ares_struct.proto"\xef\x01\n\x14DeviceConnectionInfo\x12\x13\n\x0bdevice_name\x18\x01 \x01(\t\x12\x11\n\tdevice_id\x18\x02 \x01(\t\x12\x11\n\tsimulated\x18\x03 \x01(\x08\x12L\n\x16serial_connection_info\x18\x04 \x01(\x0b2\'.ares.datamodel.device.SerialConnectionH\x00\x88\x01\x01\x123\n\x0fdevice_settings\x18\x05 \x01(\x0b2\x1a.ares.datamodel.AresStructB\x19\n\x17_serial_connection_info"q\n\x10SerialConnection\x12\x11\n\tport_name\x18\x01 \x01(\t\x12\x16\n\tserial_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tbaud_rate\x18\x03 \x01(\x05H\x01\x88\x01\x01B\x0c\n\n_serial_idB\x0c\n\n_baud_rateb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.device_connection_info_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_DEVICECONNECTIONINFO']._serialized_start = 82
    _globals['_DEVICECONNECTIONINFO']._serialized_end = 321
    _globals['_SERIALCONNECTION']._serialized_start = 323
    _globals['_SERIALCONNECTION']._serialized_end = 436


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'device/remote/remote_connection_info.proto')
_sym_db = _symbol_database.Default()
from ...device import device_connection_info_pb2 as device_dot_device__connection__info__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*device/remote/remote_connection_info.proto\x12\x15ares.datamodel.device\x1a#device/device_connection_info.proto"m\n\x14RemoteConnectionInfo\x12D\n\x0fconnection_info\x18\x01 \x01(\x0b2+.ares.datamodel.device.DeviceConnectionInfo\x12\x0f\n\x07address\x18\x02 \x01(\tb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.remote.remote_connection_info_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_REMOTECONNECTIONINFO']._serialized_start = 106
    _globals['_REMOTECONNECTIONINFO']._serialized_end = 215


from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class SymbolTag(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SYMBOL_TAG_UNSPECIFIED: _ClassVar[SymbolTag]
    SYMBOL_TAG_DEPRECATED: _ClassVar[SymbolTag]
    SYMBOL_TAG_READ_ONLY: _ClassVar[SymbolTag]
    SYMBOL_TAG_STATIC: _ClassVar[SymbolTag]
    SYMBOL_TAG_EXTENSION: _ClassVar[SymbolTag]
    SYMBOL_TAG_USER_DEFINED: _ClassVar[SymbolTag]
    SYMBOL_TAG_EXPERIMENTAL: _ClassVar[SymbolTag]
    SYMBOL_TAG_LAMBDA: _ClassVar[SymbolTag]
SYMBOL_TAG_UNSPECIFIED: SymbolTag
SYMBOL_TAG_DEPRECATED: SymbolTag
SYMBOL_TAG_READ_ONLY: SymbolTag
SYMBOL_TAG_STATIC: SymbolTag
SYMBOL_TAG_EXTENSION: SymbolTag
SYMBOL_TAG_USER_DEFINED: SymbolTag
SYMBOL_TAG_EXPERIMENTAL: SymbolTag
SYMBOL_TAG_LAMBDA: SymbolTag



"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings
from . import ares_scripting_service_pb2 as ares__scripting__service__pb2
GRPC_GENERATED_VERSION = '1.78.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(f'The grpc package installed is at version {GRPC_VERSION},' + ' but the generated code in ares_scripting_service_pb2_grpc.py depends on' + f' grpcio>={GRPC_GENERATED_VERSION}.' + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}' + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.')

class AresScriptingServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ExecuteScript = channel.unary_stream('/ares.services.AresScriptingService/ExecuteScript', request_serializer=ares__scripting__service__pb2.ScriptExecutionRequest.SerializeToString, response_deserializer=ares__scripting__service__pb2.ScriptExecutionEvent.FromString, _registered_method=True)
        self.GetCompletions = channel.unary_unary('/ares.services.AresScriptingService/GetCompletions', request_serializer=ares__scripting__service__pb2.CompletionRequest.SerializeToString, response_deserializer=ares__scripting__service__pb2.CompletionResponse.FromString, _registered_method=True)
        self.ValidateScript = channel.unary_unary('/ares.services.AresScriptingService/ValidateScript', request_serializer=ares__scripting__service__pb2.ValidateScriptRequest.SerializeToString, response_deserializer=ares__scripting__service__pb2.ValidateScriptResponse.FromString, _registered_method=True)
        self.GetScriptSummary = channel.unary_unary('/ares.services.AresScriptingService/GetScriptSummary', request_serializer=ares__scripting__service__pb2.ScriptSummaryRequest.SerializeToString, response_deserializer=ares__scripting__service__pb2.ScriptSummaryResponse.FromString, _registered_method=True)
        self.GetSymbolMetadata = channel.unary_unary('/ares.services.AresScriptingService/GetSymbolMetadata', request_serializer=ares__scripting__service__pb2.SymbolMetadataRequest.SerializeToString, response_deserializer=ares__scripting__service__pb2.SymbolMetadataResponse.FromString, _registered_method=True)
        self.GetReferences = channel.unary_unary('/ares.services.AresScriptingService/GetReferences', request_serializer=ares__scripting__service__pb2.ReferencesRequest.SerializeToString, response_deserializer=ares__scripting__service__pb2.ReferencesResponse.FromString, _registered_method=True)
        self.GetSignatureHelp = channel.unary_unary('/ares.services.AresScriptingService/GetSignatureHelp', request_serializer=ares__scripting__service__pb2.SignatureHelpRequest.SerializeToString, response_deserializer=ares__scripting__service__pb2.SignatureHelpResponse.FromString, _registered_method=True)

class AresScriptingServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ExecuteScript(self, request, context):
        """Executes a script and streams the output.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCompletions(self, request, context):
        """Dynamic context-aware suggestions based on cursor position.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateScript(self, request, context):
        """Checks for syntax errors or invalid variable references without running
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetScriptSummary(self, request, context):
        """Builds an ordered summary of function calls found in the script.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSymbolMetadata(self, request, context):
        """Resolves metadata for the symbol at a cursor location.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetReferences(self, request, context):
        """Resolves references for the symbol at a cursor location.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSignatureHelp(self, request, context):
        """Resolves function signatures for call-site help at a cursor location.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_AresScriptingServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {'ExecuteScript': grpc.unary_stream_rpc_method_handler(servicer.ExecuteScript, request_deserializer=ares__scripting__service__pb2.ScriptExecutionRequest.FromString, response_serializer=ares__scripting__service__pb2.ScriptExecutionEvent.SerializeToString), 'GetCompletions': grpc.unary_unary_rpc_method_handler(servicer.GetCompletions, request_deserializer=ares__scripting__service__pb2.CompletionRequest.FromString, response_serializer=ares__scripting__service__pb2.CompletionResponse.SerializeToString), 'ValidateScript': grpc.unary_unary_rpc_method_handler(servicer.ValidateScript, request_deserializer=ares__scripting__service__pb2.ValidateScriptRequest.FromString, response_serializer=ares__scripting__service__pb2.ValidateScriptResponse.SerializeToString), 'GetScriptSummary': grpc.unary_unary_rpc_method_handler(servicer.GetScriptSummary, request_deserializer=ares__scripting__service__pb2.ScriptSummaryRequest.FromString, response_serializer=ares__scripting__service__pb2.ScriptSummaryResponse.SerializeToString), 'GetSymbolMetadata': grpc.unary_unary_rpc_method_handler(servicer.GetSymbolMetadata, request_deserializer=ares__scripting__service__pb2.SymbolMetadataRequest.FromString, response_serializer=ares__scripting__service__pb2.SymbolMetadataResponse.SerializeToString), 'GetReferences': grpc.unary_unary_rpc_method_handler(servicer.GetReferences, request_deserializer=ares__scripting__service__pb2.ReferencesRequest.FromString, response_serializer=ares__scripting__service__pb2.ReferencesResponse.SerializeToString), 'GetSignatureHelp': grpc.unary_unary_rpc_method_handler(servicer.GetSignatureHelp, request_deserializer=ares__scripting__service__pb2.SignatureHelpRequest.FromString, response_serializer=ares__scripting__service__pb2.SignatureHelpResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('ares.services.AresScriptingService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ares.services.AresScriptingService', rpc_method_handlers)

class AresScriptingService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ExecuteScript(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_stream(request, target, '/ares.services.AresScriptingService/ExecuteScript', ares__scripting__service__pb2.ScriptExecutionRequest.SerializeToString, ares__scripting__service__pb2.ScriptExecutionEvent.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetCompletions(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresScriptingService/GetCompletions', ares__scripting__service__pb2.CompletionRequest.SerializeToString, ares__scripting__service__pb2.CompletionResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def ValidateScript(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresScriptingService/ValidateScript', ares__scripting__service__pb2.ValidateScriptRequest.SerializeToString, ares__scripting__service__pb2.ValidateScriptResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetScriptSummary(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresScriptingService/GetScriptSummary', ares__scripting__service__pb2.ScriptSummaryRequest.SerializeToString, ares__scripting__service__pb2.ScriptSummaryResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetSymbolMetadata(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresScriptingService/GetSymbolMetadata', ares__scripting__service__pb2.SymbolMetadataRequest.SerializeToString, ares__scripting__service__pb2.SymbolMetadataResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetReferences(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresScriptingService/GetReferences', ares__scripting__service__pb2.ReferencesRequest.SerializeToString, ares__scripting__service__pb2.ReferencesResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetSignatureHelp(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresScriptingService/GetSignatureHelp', ares__scripting__service__pb2.SignatureHelpRequest.SerializeToString, ares__scripting__service__pb2.SignatureHelpResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)


from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class AresDeviceDescription(_message.Message):
    __slots__ = ("device_name", "device_id")
    DEVICE_NAME_FIELD_NUMBER: _ClassVar[int]
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    device_name: str
    device_id: str
    def __init__(self, device_name: _Optional[str] = ..., device_id: _Optional[str] = ...) -> None: ...



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_data_schema.proto')
_sym_db = _symbol_database.Default()
from . import ares_data_type_pb2 as ares__data__type__pb2
from . import ares_quantity_type_pb2 as ares__quantity__type__pb2
from . import ares_struct_pb2 as ares__struct__pb2
from . import limits_pb2 as limits__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16ares_data_schema.proto\x12\x0eares.datamodel\x1a\x14ares_data_type.proto\x1a\x18ares_quantity_type.proto\x1a\x11ares_struct.proto\x1a\x0climits.proto"\xa0\x01\n\x10AresStructSchema\x12<\n\x06fields\x18\x01 \x03(\x0b2,.ares.datamodel.AresStructSchema.FieldsEntry\x1aN\n\x0bFieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12.\n\x05value\x18\x02 \x01(\x0b2\x1f.ares.datamodel.AresValueSchema:\x028\x01"\xa9\x04\n\x0fAresValueSchema\x12*\n\x04type\x18\x01 \x01(\x0e2\x1c.ares.datamodel.AresDataType\x12\x10\n\x08optional\x18\x02 \x01(\x08\x12\x13\n\x0bdescription\x18\x03 \x01(\t\x127\n\x0fquantity_schema\x18\x04 \x01(\x0b2\x1e.ares.datamodel.QuantitySchema\x125\n\x0estring_choices\x18\x05 \x01(\x0b2\x1b.ares.datamodel.StringArrayH\x00\x125\n\x0enumber_choices\x18\x06 \x01(\x0b2\x1b.ares.datamodel.NumberArrayH\x00\x12(\n\x06limits\x18\x07 \x01(\x0b2\x16.ares.datamodel.LimitsH\x00\x127\n\rstruct_schema\x18\x08 \x01(\x0b2 .ares.datamodel.AresStructSchema\x12<\n\x13list_element_schema\x18\t \x01(\x0b2\x1f.ares.datamodel.AresValueSchema\x12\x1d\n\x10min_number_value\x18\n \x01(\x01H\x01\x88\x01\x01\x12\x1d\n\x10max_number_value\x18\x0b \x01(\x01H\x02\x88\x01\x01B\x13\n\x11available_choicesB\x13\n\x11_min_number_valueB\x13\n\x11_max_number_value"\xc2\x01\n\x0eQuantitySchema\x123\n\rquantity_type\x18\x01 \x01(\x0e2\x1c.ares.datamodel.QuantityType\x12\x13\n\x0bbounds_unit\x18\x02 \x01(\t\x12\x1d\n\x10min_scalar_value\x18\x03 \x01(\x01H\x00\x88\x01\x01\x12\x1d\n\x10max_scalar_value\x18\x04 \x01(\x01H\x01\x88\x01\x01B\x13\n\x11_min_scalar_valueB\x13\n\x11_max_scalar_valueb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_data_schema_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_ARESSTRUCTSCHEMA_FIELDSENTRY']._loaded_options = None
    _globals['_ARESSTRUCTSCHEMA_FIELDSENTRY']._serialized_options = b'8\x01'
    _globals['_ARESSTRUCTSCHEMA']._serialized_start = 124
    _globals['_ARESSTRUCTSCHEMA']._serialized_end = 284
    _globals['_ARESSTRUCTSCHEMA_FIELDSENTRY']._serialized_start = 206
    _globals['_ARESSTRUCTSCHEMA_FIELDSENTRY']._serialized_end = 284
    _globals['_ARESVALUESCHEMA']._serialized_start = 287
    _globals['_ARESVALUESCHEMA']._serialized_end = 840
    _globals['_QUANTITYSCHEMA']._serialized_start = 843
    _globals['_QUANTITYSCHEMA']._serialized_end = 1037


from analyzing import analysis_pb2 as _analysis_pb2
import ares_struct_pb2 as _ares_struct_pb2
import request_metadata_pb2 as _request_metadata_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from analyzing import analyzer_capabilities_pb2 as _analyzer_capabilities_pb2
import ares_data_schema_pb2 as _ares_data_schema_pb2
from connection import connection_status_pb2 as _connection_status_pb2
from connection import connection_info_pb2 as _connection_info_pb2
from connection import connection_state_pb2 as _connection_state_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ParameterValidationRequest(_message.Message):
    __slots__ = ("input_schema",)
    INPUT_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    input_schema: _ares_data_schema_pb2.AresStructSchema
    def __init__(self, input_schema: _Optional[_Union[_ares_data_schema_pb2.AresStructSchema, _Mapping]] = ...) -> None: ...

class ParameterValidationResult(_message.Message):
    __slots__ = ("success", "messages")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    success: bool
    messages: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, success: bool = ..., messages: _Optional[_Iterable[str]] = ...) -> None: ...

class AnalysisRequest(_message.Message):
    __slots__ = ("inputs", "settings", "metadata")
    INPUTS_FIELD_NUMBER: _ClassVar[int]
    SETTINGS_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    inputs: _ares_struct_pb2.AresStruct
    settings: _ares_struct_pb2.AresStruct
    metadata: _request_metadata_pb2.RequestMetadata
    def __init__(self, inputs: _Optional[_Union[_ares_struct_pb2.AresStruct, _Mapping]] = ..., settings: _Optional[_Union[_ares_struct_pb2.AresStruct, _Mapping]] = ..., metadata: _Optional[_Union[_request_metadata_pb2.RequestMetadata, _Mapping]] = ...) -> None: ...

class AnalysisParametersResponse(_message.Message):
    __slots__ = ("parameter_schema",)
    PARAMETER_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    parameter_schema: _ares_data_schema_pb2.AresStructSchema
    def __init__(self, parameter_schema: _Optional[_Union[_ares_data_schema_pb2.AresStructSchema, _Mapping]] = ...) -> None: ...



import ares_notification_pb2 as _ares_notification_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NotificationRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class NotificationResponse(_message.Message):
    __slots__ = ("notifications",)
    NOTIFICATIONS_FIELD_NUMBER: _ClassVar[int]
    notifications: _containers.RepeatedCompositeFieldContainer[_ares_notification_pb2.AresNotification]
    def __init__(self, notifications: _Optional[_Iterable[_Union[_ares_notification_pb2.AresNotification, _Mapping]]] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class SymbolKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SYMBOL_KIND_UNSPECIFIED: _ClassVar[SymbolKind]
    SYMBOL_KIND_DEVICE: _ClassVar[SymbolKind]
    SYMBOL_KIND_FUNCTION: _ClassVar[SymbolKind]
    SYMBOL_KIND_VARIABLE: _ClassVar[SymbolKind]
    SYMBOL_KIND_STRUCT: _ClassVar[SymbolKind]
    SYMBOL_KIND_KEYWORD: _ClassVar[SymbolKind]
    SYMBOL_KIND_PLANNER: _ClassVar[SymbolKind]
    SYMBOL_KIND_ANALYZER: _ClassVar[SymbolKind]
    SYMBOL_KIND_TYPE: _ClassVar[SymbolKind]
SYMBOL_KIND_UNSPECIFIED: SymbolKind
SYMBOL_KIND_DEVICE: SymbolKind
SYMBOL_KIND_FUNCTION: SymbolKind
SYMBOL_KIND_VARIABLE: SymbolKind
SYMBOL_KIND_STRUCT: SymbolKind
SYMBOL_KIND_KEYWORD: SymbolKind
SYMBOL_KIND_PLANNER: SymbolKind
SYMBOL_KIND_ANALYZER: SymbolKind
SYMBOL_KIND_TYPE: SymbolKind



import ares_data_type_pb2 as _ares_data_type_pb2
import ares_quantity_type_pb2 as _ares_quantity_type_pb2
import ares_struct_pb2 as _ares_struct_pb2
import limits_pb2 as _limits_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AresStructSchema(_message.Message):
    __slots__ = ("fields",)
    class FieldsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: AresValueSchema
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[AresValueSchema, _Mapping]] = ...) -> None: ...
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    fields: _containers.MessageMap[str, AresValueSchema]
    def __init__(self, fields: _Optional[_Mapping[str, AresValueSchema]] = ...) -> None: ...

class AresValueSchema(_message.Message):
    __slots__ = ("type", "optional", "description", "quantity_schema", "string_choices", "number_choices", "limits", "struct_schema", "list_element_schema", "min_number_value", "max_number_value")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    OPTIONAL_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    QUANTITY_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    STRING_CHOICES_FIELD_NUMBER: _ClassVar[int]
    NUMBER_CHOICES_FIELD_NUMBER: _ClassVar[int]
    LIMITS_FIELD_NUMBER: _ClassVar[int]
    STRUCT_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    LIST_ELEMENT_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    MIN_NUMBER_VALUE_FIELD_NUMBER: _ClassVar[int]
    MAX_NUMBER_VALUE_FIELD_NUMBER: _ClassVar[int]
    type: _ares_data_type_pb2.AresDataType
    optional: bool
    description: str
    quantity_schema: QuantitySchema
    string_choices: _ares_struct_pb2.StringArray
    number_choices: _ares_struct_pb2.NumberArray
    limits: _limits_pb2.Limits
    struct_schema: AresStructSchema
    list_element_schema: AresValueSchema
    min_number_value: float
    max_number_value: float
    def __init__(self, type: _Optional[_Union[_ares_data_type_pb2.AresDataType, str]] = ..., optional: bool = ..., description: _Optional[str] = ..., quantity_schema: _Optional[_Union[QuantitySchema, _Mapping]] = ..., string_choices: _Optional[_Union[_ares_struct_pb2.StringArray, _Mapping]] = ..., number_choices: _Optional[_Union[_ares_struct_pb2.NumberArray, _Mapping]] = ..., limits: _Optional[_Union[_limits_pb2.Limits, _Mapping]] = ..., struct_schema: _Optional[_Union[AresStructSchema, _Mapping]] = ..., list_element_schema: _Optional[_Union[AresValueSchema, _Mapping]] = ..., min_number_value: _Optional[float] = ..., max_number_value: _Optional[float] = ...) -> None: ...

class QuantitySchema(_message.Message):
    __slots__ = ("quantity_type", "bounds_unit", "min_scalar_value", "max_scalar_value")
    QUANTITY_TYPE_FIELD_NUMBER: _ClassVar[int]
    BOUNDS_UNIT_FIELD_NUMBER: _ClassVar[int]
    MIN_SCALAR_VALUE_FIELD_NUMBER: _ClassVar[int]
    MAX_SCALAR_VALUE_FIELD_NUMBER: _ClassVar[int]
    quantity_type: _ares_quantity_type_pb2.QuantityType
    bounds_unit: str
    min_scalar_value: float
    max_scalar_value: float
    def __init__(self, quantity_type: _Optional[_Union[_ares_quantity_type_pb2.QuantityType, str]] = ..., bounds_unit: _Optional[str] = ..., min_scalar_value: _Optional[float] = ..., max_scalar_value: _Optional[float] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ValidationResult(_message.Message):
    __slots__ = ("success", "messages")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    success: bool
    messages: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, success: bool = ..., messages: _Optional[_Iterable[str]] = ...) -> None: ...



"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings
from . import ares_notification_pb2 as ares__notification__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
GRPC_GENERATED_VERSION = '1.78.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(f'The grpc package installed is at version {GRPC_VERSION},' + ' but the generated code in ares_notification_pb2_grpc.py depends on' + f' grpcio>={GRPC_GENERATED_VERSION}.' + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}' + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.')

class AresNotificationRpcStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Subscribe = channel.unary_stream('/ares.services.AresNotificationRpc/Subscribe', request_serializer=ares__notification__pb2.SubscriptionRequest.SerializeToString, response_deserializer=ares__notification__pb2.AresNotification.FromString, _registered_method=True)
        self.GetUpdatedNotificationList = channel.unary_unary('/ares.services.AresNotificationRpc/GetUpdatedNotificationList', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=ares__notification__pb2.NotificationsList.FromString, _registered_method=True)

class AresNotificationRpcServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Subscribe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUpdatedNotificationList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_AresNotificationRpcServicer_to_server(servicer, server):
    rpc_method_handlers = {'Subscribe': grpc.unary_stream_rpc_method_handler(servicer.Subscribe, request_deserializer=ares__notification__pb2.SubscriptionRequest.FromString, response_serializer=ares__notification__pb2.AresNotification.SerializeToString), 'GetUpdatedNotificationList': grpc.unary_unary_rpc_method_handler(servicer.GetUpdatedNotificationList, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=ares__notification__pb2.NotificationsList.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('ares.services.AresNotificationRpc', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ares.services.AresNotificationRpc', rpc_method_handlers)

class AresNotificationRpc(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Subscribe(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_stream(request, target, '/ares.services.AresNotificationRpc/Subscribe', ares__notification__pb2.SubscriptionRequest.SerializeToString, ares__notification__pb2.AresNotification.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetUpdatedNotificationList(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.AresNotificationRpc/GetUpdatedNotificationList', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, ares__notification__pb2.NotificationsList.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)


import ares_struct_pb2 as _ares_struct_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DeviceCommandArgument(_message.Message):
    __slots__ = ("arg_name", "arg_value")
    ARG_NAME_FIELD_NUMBER: _ClassVar[int]
    ARG_VALUE_FIELD_NUMBER: _ClassVar[int]
    arg_name: str
    arg_value: _ares_struct_pb2.AresValue
    def __init__(self, arg_name: _Optional[str] = ..., arg_value: _Optional[_Union[_ares_struct_pb2.AresValue, _Mapping]] = ...) -> None: ...



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'templates/internal_variable.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!templates/internal_variable.proto\x12\x18ares.datamodel.templates"\xa1\x01\n\x1aInternalVariableAllocation\x12\x16\n\tunique_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12N\n\x16internal_variable_type\x18\x02 \x01(\x0e2..ares.datamodel.templates.InternalVariableType\x12\r\n\x05value\x18\x03 \x01(\tB\x0c\n\n_unique_id*~\n\x14InternalVariableType\x12\x13\n\x0fVAR_UNSPECIFIED\x10\x00\x12\x1d\n\x19CURRENT_EXPERIMENT_NUMBER\x10\x01\x12\x17\n\x13CURRENT_CAMPAIGN_ID\x10\x02\x12\x19\n\x15CURRENT_CAMPAIGN_NAME\x10\x03b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'templates.internal_variable_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_INTERNALVARIABLETYPE']._serialized_start = 227
    _globals['_INTERNALVARIABLETYPE']._serialized_end = 353
    _globals['_INTERNALVARIABLEALLOCATION']._serialized_start = 64
    _globals['_INTERNALVARIABLEALLOCATION']._serialized_end = 225


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'scripting/symbol_tag.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ascripting/symbol_tag.proto\x12\x18ares.datamodel.scripting*\xde\x01\n\tSymbolTag\x12\x1a\n\x16SYMBOL_TAG_UNSPECIFIED\x10\x00\x12\x19\n\x15SYMBOL_TAG_DEPRECATED\x10\x01\x12\x18\n\x14SYMBOL_TAG_READ_ONLY\x10\x02\x12\x15\n\x11SYMBOL_TAG_STATIC\x10\x03\x12\x18\n\x14SYMBOL_TAG_EXTENSION\x10\x04\x12\x1b\n\x17SYMBOL_TAG_USER_DEFINED\x10\x05\x12\x1b\n\x17SYMBOL_TAG_EXPERIMENTAL\x10\x06\x12\x15\n\x11SYMBOL_TAG_LAMBDA\x10\x07b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scripting.symbol_tag_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_SYMBOLTAG']._serialized_start = 57
    _globals['_SYMBOLTAG']._serialized_end = 279


import validation_result_pb2 as _validation_result_pb2
from analyzing import analysis_pb2 as _analysis_pb2
import ares_struct_pb2 as _ares_struct_pb2
import ares_data_schema_pb2 as _ares_data_schema_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AnalysisRequest(_message.Message):
    __slots__ = ("analyzer_id", "inputs", "settings")
    ANALYZER_ID_FIELD_NUMBER: _ClassVar[int]
    INPUTS_FIELD_NUMBER: _ClassVar[int]
    SETTINGS_FIELD_NUMBER: _ClassVar[int]
    analyzer_id: str
    inputs: _ares_struct_pb2.AresStruct
    settings: _ares_struct_pb2.AresStruct
    def __init__(self, analyzer_id: _Optional[str] = ..., inputs: _Optional[_Union[_ares_struct_pb2.AresStruct, _Mapping]] = ..., settings: _Optional[_Union[_ares_struct_pb2.AresStruct, _Mapping]] = ...) -> None: ...

class InputValidationRequest(_message.Message):
    __slots__ = ("analyzer_id", "input_schema")
    ANALYZER_ID_FIELD_NUMBER: _ClassVar[int]
    INPUT_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    analyzer_id: str
    input_schema: _ares_data_schema_pb2.AresStructSchema
    def __init__(self, analyzer_id: _Optional[str] = ..., input_schema: _Optional[_Union[_ares_data_schema_pb2.AresStructSchema, _Mapping]] = ...) -> None: ...

class AnalyzerParametersRequest(_message.Message):
    __slots__ = ("analyzer_id",)
    ANALYZER_ID_FIELD_NUMBER: _ClassVar[int]
    analyzer_id: str
    def __init__(self, analyzer_id: _Optional[str] = ...) -> None: ...

class AnalyzerParametersResponse(_message.Message):
    __slots__ = ("analysis_schema",)
    ANALYSIS_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    analysis_schema: _ares_data_schema_pb2.AresStructSchema
    def __init__(self, analysis_schema: _Optional[_Union[_ares_data_schema_pb2.AresStructSchema, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DiagnosticSeverity(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    DIAGNOSTIC_SEVERITY_ERROR: _ClassVar[DiagnosticSeverity]
    DIAGNOSTIC_SEVERITY_WARNING: _ClassVar[DiagnosticSeverity]
    DIAGNOSTIC_SEVERITY_INFO: _ClassVar[DiagnosticSeverity]
    DIAGNOSTIC_SEVERITY_HINT: _ClassVar[DiagnosticSeverity]
DIAGNOSTIC_SEVERITY_ERROR: DiagnosticSeverity
DIAGNOSTIC_SEVERITY_WARNING: DiagnosticSeverity
DIAGNOSTIC_SEVERITY_INFO: DiagnosticSeverity
DIAGNOSTIC_SEVERITY_HINT: DiagnosticSeverity

class Diagnostic(_message.Message):
    __slots__ = ("start_line", "start_column", "end_line", "end_column", "message", "severity", "code")
    START_LINE_FIELD_NUMBER: _ClassVar[int]
    START_COLUMN_FIELD_NUMBER: _ClassVar[int]
    END_LINE_FIELD_NUMBER: _ClassVar[int]
    END_COLUMN_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    SEVERITY_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    start_line: int
    start_column: int
    end_line: int
    end_column: int
    message: str
    severity: DiagnosticSeverity
    code: str
    def __init__(self, start_line: _Optional[int] = ..., start_column: _Optional[int] = ..., end_line: _Optional[int] = ..., end_column: _Optional[int] = ..., message: _Optional[str] = ..., severity: _Optional[_Union[DiagnosticSeverity, str]] = ..., code: _Optional[str] = ...) -> None: ...



from scripting import script_symbol_metadata_pb2 as _script_symbol_metadata_pb2
from scripting import symbol_kind_pb2 as _symbol_kind_pb2
import ares_data_schema_pb2 as _ares_data_schema_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class InsertTextFormat(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    INSERT_TEXT_FORMAT_PLAIN_TEXT: _ClassVar[InsertTextFormat]
    INSERT_TEXT_FORMAT_SNIPPET: _ClassVar[InsertTextFormat]
INSERT_TEXT_FORMAT_PLAIN_TEXT: InsertTextFormat
INSERT_TEXT_FORMAT_SNIPPET: InsertTextFormat

class CompletionItem(_message.Message):
    __slots__ = ("label", "insert_text", "insert_text_format", "sort_text", "metadata", "detail", "documentation", "kind", "parent_identifier", "input_schema", "output_schema", "schema")
    LABEL_FIELD_NUMBER: _ClassVar[int]
    INSERT_TEXT_FIELD_NUMBER: _ClassVar[int]
    INSERT_TEXT_FORMAT_FIELD_NUMBER: _ClassVar[int]
    SORT_TEXT_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    DETAIL_FIELD_NUMBER: _ClassVar[int]
    DOCUMENTATION_FIELD_NUMBER: _ClassVar[int]
    KIND_FIELD_NUMBER: _ClassVar[int]
    PARENT_IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    INPUT_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    label: str
    insert_text: str
    insert_text_format: InsertTextFormat
    sort_text: str
    metadata: _script_symbol_metadata_pb2.ScriptSymbolMetadata
    detail: str
    documentation: str
    kind: _symbol_kind_pb2.SymbolKind
    parent_identifier: str
    input_schema: _ares_data_schema_pb2.AresStructSchema
    output_schema: _ares_data_schema_pb2.AresValueSchema
    schema: _ares_data_schema_pb2.AresValueSchema
    def __init__(self, label: _Optional[str] = ..., insert_text: _Optional[str] = ..., insert_text_format: _Optional[_Union[InsertTextFormat, str]] = ..., sort_text: _Optional[str] = ..., metadata: _Optional[_Union[_script_symbol_metadata_pb2.ScriptSymbolMetadata, _Mapping]] = ..., detail: _Optional[str] = ..., documentation: _Optional[str] = ..., kind: _Optional[_Union[_symbol_kind_pb2.SymbolKind, str]] = ..., parent_identifier: _Optional[str] = ..., input_schema: _Optional[_Union[_ares_data_schema_pb2.AresStructSchema, _Mapping]] = ..., output_schema: _Optional[_Union[_ares_data_schema_pb2.AresValueSchema, _Mapping]] = ..., schema: _Optional[_Union[_ares_data_schema_pb2.AresValueSchema, _Mapping]] = ...) -> None: ...
